@@ -1,7 +1,7 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -12,6 +12,7 @@ use Moose;
 use Test::More;
 use IO::Socket::INET;
 use ElasticSearchX::Model;
+use Search::Elasticsearch;
 use version;
 
 index twitter => ( namespace => 'MyModel' );
@@ -20,15 +21,17 @@ sub testing {
     my $class = shift;
     unless ( IO::Socket::INET->new('127.0.0.1:9900') ) {
         plan skip_all =>
-            'Requires an ElasticSearch server running on port 9900';
+            'Requires an Elasticsearch server running on port 9900';
     }
 
-    my $model = $class->new( es => ':9900' );
-    if ( $model->es_version < 0.019002 ) {
-        plan skip_all => 'Requires ElasticSearch 0.19.2';
+    my $model = $class->new( es => Search::Elasticsearch->new(
+        nodes => $ENV{ES}||"localhost:9900",
+        # trace_to => "Stderr",
+    ) );
+    if ( $model->es_version < 1 ) {
+        plan skip_all => 'Requires Elasticsearch 1.0.0';
     }
 
-    # $model->es->trace_calls(1);
     ok( $model->deploy( delete => 1 ), 'Deploy ok' );
     return $model;
 }
